summaryrefslogtreecommitdiff
path: root/tinyusb/tusb_hal.h
diff options
context:
space:
mode:
Diffstat (limited to 'tinyusb/tusb_hal.h')
-rw-r--r--tinyusb/tusb_hal.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tinyusb/tusb_hal.h b/tinyusb/tusb_hal.h
index 1d46bcd20..33d44c873 100644
--- a/tinyusb/tusb_hal.h
+++ b/tinyusb/tusb_hal.h
@@ -74,18 +74,18 @@ extern "C" {
bool hal_usb_init(void);
/** \brief Enable USB Interrupt on a specific USB Controller
* \param[in] coreid is a zero-based index to identify USB controller's ID
* \note Some MCUs such as NXP LPC43xx has multiple USB controllers. It is necessary to know which USB controller for
* those MCUs.
*/
-void hal_usb_int_enable(uint8_t coreid);
+void hal_usb_int_enable(uint8_t port);
/** \brief Disable USB Interrupt on a specific USB Controller
* \param[in] coreid is a zero-based index to identify USB controller's ID
* \note Some MCUs such as NXP LPC43xx has multiple USB controllers. It is necessary to know which USB controller for
* those MCUs.
*/
-void hal_usb_int_disable(uint8_t coreid);
+void hal_usb_int_disable(uint8_t port);
@@ -74,18 +74,18 @@ extern "C" {
bool hal_usb_init(void);
/** \brief Enable USB Interrupt on a specific USB Controller
- * \param[in] coreid is a zero-based index to identify USB controller's ID
+ * \param[in] port is a zero-based index to identify USB controller's ID
* \note Some MCUs such as NXP LPC43xx has multiple USB controllers. It is necessary to know which USB controller for
* those MCUs.
@@ -74,18 +74,18 @@ extern "C" {
/** \brief Disable USB Interrupt on a specific USB Controller
- * \param[in] coreid is a zero-based index to identify USB controller's ID
+ * \param[in] port is a zero-based index to identify USB controller's ID
* \note Some MCUs such as NXP LPC43xx has multiple USB controllers. It is necessary to know which USB controller for
* those MCUs.